@@ -1,20 +1,22 @@
 
 # oXim package: Oxycline Index from Matrix Echograms ---------------
-#' @import R.matlab
+#' @importFrom R.matlab readMat
+#' @importFrom imagine convolutionQuantile
 #' @import graphics
 #' @import stats
 #' @import sp
-#' @import gstat
+#' @importFrom gstat idw
 #'
 #' @title Oxycline Index from Matrix Echograms
 #'
 #' @author Wencheng Lau-Medrano, \email{luis.laum@gmail.com}
 #' @name oXim-package
-#' @description Pack oriented to extract oxycline depth from echogram matrix using median-filter and 2D-convolution based algorithms.
+#' @description Tools for oxycline depth calculation from echogram matrices
 #' @aliases oXim-package oXim
 #' @docType package
-#' @references oXim: Oxycline Index from Matrix Echograms (RJournal)
 #' @keywords echograms, oxycline, depth, image-filtering
+#' @exportClass echoData
+#' @exportClass oxyclineData
 NULL
 
 #' @title Takes outputs from Echopen and generates a matrix to calculate Oxycline.
@@ -23,15 +25,19 @@ NULL
 #'
 #' @param fileMode List with needed variables to read single Matlab files. See details below.
 #' @param directoryMode List with needed variables to read Matlab files from directory. See details below.
-#' @param validFish38 Range of valid values for Fish-38kHz
-#' @param validBlue38 Range of valid values for Blue-38kHz
-#' @param upLimitFluid120 Upper limit for Fluidlike-120kHz
+#' @param validFish38 Range of valid values for Fish-38kHz.
+#' @param validBlue38 Range of valid values for Blue-38kHz.
+#' @param upLimitFluid120 Upper limit for Fluidlike-120kHz.
 #' @param pinInterval Time threshold (in secs) to consider separate two matrices (echograms).
 #' @param date.format A character string. The default method is \code{\%Y-\%m-\%d \%H:\%M:\%S}.
 #'
-#' @details \code{fileMode} must be a list contains filenames for Fish38, Fluid120 and Bluelike38.
-#' For \code{directoryMode}, it must be a list with a directory with Fish38, Fluid120 and Bluelike38
-#' files in order to group and build final echograms.
+#' @details \code{fileMode} must be a \code{list} with the next structure: \code{fish38_file} (directory for fish38 file),
+#' \code{blue38_file} (directory for blue38 file) and \code{fluid120_file} (directory for fluid120 file).
+#'
+#' Similarly, \code{directoryMode} must be a \code{list} with the next structure: \code{directory} (folder
+#' where the files are storaged), \code{fish38_pattern} (text pattern for recognizing fish38 files),
+#' \code{blue38_pattern} (text pattern for recognizing blue38 files) and \code{fluid120_pattern}
+#' (text pattern for recognizing fluid120 files).
 #'
 #' @examples
 #' fileMode <- list(fish38_file   = system.file("extdata", "fish38.mat", package = "oXim"),
@@ -41,7 +47,6 @@ NULL
 #' print(echoData)
 #'
 #' @export
-#' @exportClass echoData
 readEchograms <- function(fileMode = NULL, directoryMode = NULL,
                           validFish38 = c(-100, -21), validBlue38 = c(-100, -56),
                           upLimitFluid120 = -53, pinInterval = 50, date.format = "%d-%m-%Y %H:%M:%S"){
@@ -62,22 +67,21 @@ readEchograms <- function(fileMode = NULL, directoryMode = NULL,
 #' @param filterSettings List with combination of filters.
 #' @param stepBYstep \code{logical}. If \code{FALSE} (default), returns just original and final echogram, otherwise each
 #' echogram (after applying filters one by one) will be returned.
+#' @param ... Not used
 #'
 #' @details If \code{filterSettings = NULL}, oXim will use filter configuration present on \code{defaultFilterSettings}
 #' data set. For extra details about image filters, see \code{\link{createFilterSetting}} help.
 #'
 #' @examples
-#' \dontrun{
 #' fileMode <- list(fish38_file   = system.file("extdata", "fish38.mat", package = "oXim"),
 #'                  fluid120_file = system.file("extdata", "fluid120.mat", package = "oXim"),
 #'                  blue38_file   = system.file("extdata", "blue38.mat", package = "oXim"))
 #' echoData <- readEchograms(fileMode = fileMode)
 #' oxyLimits <- getOxyrange(fluidMatrix = echoData)
-#' }
 #'
 #' @export
 #' @exportClass oxyclineData
-getOxyrange <- function(fluidMatrix, filterSettings = NULL, stepBYstep = FALSE){
+getOxyrange <- function(fluidMatrix, filterSettings = NULL, stepBYstep = FALSE, ...){
 
   nEchograms <- fluidMatrix$info$n_echograms
 
@@ -102,7 +106,7 @@ getOxyrange <- function(fluidMatrix, filterSettings = NULL, stepBYstep = FALSE){
   names(oxyclineData) <- paste0("matrix_", seq_along(fluidMatrix))
 
   # Get ranges of depth of oxycline using the last matrix of each echogram
-  oxyRange <- .getOxyrange(oxyclineData = oxyclineData, oxyDims = oxyDims)
+  oxyRange <- .getOxyrange(oxyclineData = oxyclineData, oxyDims = oxyDims, ...)
 
   # Compile outputs on a list
   oxyclineData <- list(info = list(number_echograms = nEchograms,
@@ -135,7 +139,8 @@ getOxyrange <- function(fluidMatrix, filterSettings = NULL, stepBYstep = FALSE){
 #' @details About each parameter:
 #' \describe{
 #' \item{\strong{name}}{This parameter must be a string and it works as a short way to select an specific set of filter
-#' settings. (It will be fully available in next version.)}
+#' settings. This parameter has priority over the others, so to create a personalized set of filters, `name` will must
+#' set as \code{NULL}. (It will be fully available in next version.)}
 #' \item{\strong{type}}{This parameter must be a string and indicates what kind of filter method will be applied to the
 #' echigrams. There are two options to select: \code{.definerFilter} which works as a reverse-effect median filter
 #' and \code{.noiselessFilter} which removes  noisy signals on the echograms.}
@@ -155,8 +160,16 @@ getOxyrange <- function(fluidMatrix, filterSettings = NULL, stepBYstep = FALSE){
 #' createFilterSetting(type = ".definerFilter", radius = c(3, 5, 5))
 createFilterSetting <- function(name = "default", type = NULL, radius = NULL, times = NULL, tolerance = NULL){
 
-  if(is.null(name) || !is.vector(name) || length(name) > 1){
+  defaultFilterSettings <- get("defaultFilterSettings")
+
+  if(is.null(name) || !is.vector(name) || length(name) > 1 || !is.element(name, defaultFilterSettings$name)){
     # Check variables of fileter settings object
+    for(i in c("type", "radius", "times", "tolerance")){
+     if(is.null(get(x = i))){
+       stop("There is no valid value for ", i, ".")
+     }
+    }
+
     # Chaeck name
     if(!is.element(sort(unique(type)), c(".definerFilter", ".noiselessFilter")))
       stop("Problem with 'filterSettings'. There is, at least, one wrong value on 'type' column.")
@@ -183,7 +196,7 @@ createFilterSetting <- function(name = "default", type = NULL, radius = NULL, ti
                          tolerance = rep(tolerance, length.out = allLength),
                          stringsAsFactors = FALSE)
   }else{
-    defaultFilterSettings <- get("defaultFilterSettings")
+
     output <- subset(defaultFilterSettings, defaultFilterSettings$name == name)
   }
 
@@ -191,28 +204,29 @@ createFilterSetting <- function(name = "default", type = NULL, radius = NULL, ti
 }
 
 
-#' @export echogramPlot
-#'
 #' @title Plot a matrix of a filtered echogram.
-#' @description This function uses an oxyclineData-class object and plot .
+#' @description This function takes an echogram matrix and plot it.
 #'
-#' @param echogramOutput Object of class \code{oxyclineData} with internal echogram matrix to be plotted.
+#' @param x Object of class \code{oxyclineData}, \code{echoData} or \code{matrix} with information for make
+#' an echogram plot. If \code{x} is a \code{matrix}, column names must indicate the time and row names, the
+#' depth.
 #' @param colEchogram Pallete of colours to plot the echograms. If \code{NULL} (default) the system
 #' will use the same combination used on object \code{colPallete}.
-#' @param ... Graphical parameters for \code{\link{image}} may also passed as arguments to this function.
+#' @param ... Extra arguments passed to \code{\link{echogramPlot}} function.
+#'
+#' @details Typically, `echogramPlot` can be applied to echogram matrix object, however it also may use
+#' `echoData` and `oxyclineData` objects, as a method.
+#'
+#' @export
 #'
 #' @examples
 #' fileMode <- list(fish38_file   = system.file("extdata", "fish38.mat", package = "oXim"),
 #'                  fluid120_file = system.file("extdata", "fluid120.mat", package = "oXim"),
 #'                  blue38_file   = system.file("extdata", "blue38.mat", package = "oXim"))
 #' echoData <- readEchograms(fileMode = fileMode)
-#' echogramPlot(echoData$data$matrix_1$echogram)
-echogramPlot <- function(echogramOutput, colEchogram = "colPalette", ...){
-
-  colEchogram <- get(colEchogram)
-  .echogramPlot(echogramOutput, colEchogram = colEchogram, ...)
-
-  return(invisible())
+#' echogramPlot(x = echoData)
+echogramPlot <- function(x, colEchogram = "colPalette", ...){
+  UseMethod(generic = "echogramPlot", object = x)
 }
 
 #' @title Default color palette most using on acostic echograms.
