@@ -1,6 +1,4 @@
 
-# Calculate oxycline limits from oxyclineData object -------------------------------
-
 # Set directories where the Echopen's outputs are located
 fileMode <- list(fish38_file   = system.file("extdata", "fish38.mat", package = "oXim"),
                  fluid120_file = system.file("extdata", "fluid120.mat", package = "oXim"),
@@ -24,3 +22,6 @@ print(summaryOxyLimits)
 
 # Plot method
 plot(oxyLimits)
+
+# echogramPlot method
+echogramPlot(oxyLimits)
